@@ -15,7 +15,7 @@ class DapiClient(object):
     '''
     Dapi Connect Python API client
 
-    API documentation: https://docs.dapi.co.
+    API documentation: https://docs.dapi.com.
 
     :param  str     app_secret:          App Secret Key from Dashboard.
     '''
@@ -40,8 +40,8 @@ class DapiClient(object):
 
         headers = {
             **headers,
-            'host': 'dd.dapi.co',
-            'Host': 'dd.dapi.co'
+            'host': 'dd.dapi.com',
+            'Host': 'dd.dapi.com'
         }
 
         return request.post("", body, headers, True)
