@@ -6,7 +6,7 @@ class Operation(DapiRequest):
     def getOperationStatus(self, access_token, user_secret, operation_id, app_key):
         '''
         Return the status of an Operation
-        (`HTTP docs <https://docs.dapi.co/docs/operation-status>`__)
+        (`HTTP docs <https://docs.dapi.com/docs/operation-status>`__)
 
         :param  str     access_token:    From the exchangeToken method.
 
